@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
 """Utilities"""
 from .pre_processing import PreProcess
-from .tf_layers import Layers
+from .tf_layers import Layers, HiddenLayers
 from .tf_utilities import tf_isin, tf_log10
